==> stan4bart_0.0-2.tar.gz: stan4bart/src/include/stan/math/rev/fun.hpp <==
#ifndef STAN_MATH_REV_FUN_HPP
#define STAN_MATH_REV_FUN_HPP

#include <stan/math/prim/fun/Eigen.hpp>

#include <stan/math/rev/fun/LDLT_factor.hpp>
#include <stan/math/rev/fun/Phi.hpp>
#include <stan/math/rev/fun/Phi_approx.hpp>
#include <stan/math/rev/fun/abs.hpp>
#include <stan/math/rev/fun/accumulator.hpp>
#include <stan/math/rev/fun/acos.hpp>
#include <stan/math/rev/fun/acosh.hpp>
#include <stan/math/rev/fun/append_col.hpp>
#include <stan/math/rev/fun/append_row.hpp>
#include <stan/math/rev/fun/as_bool.hpp>
#include <stan/math/rev/fun/as_array_or_scalar.hpp>
#include <stan/math/rev/fun/as_column_vector_or_scalar.hpp>
#include <stan/math/rev/fun/arg.hpp>
#include <stan/math/rev/fun/asin.hpp>
#include <stan/math/rev/fun/asinh.hpp>
#include <stan/math/rev/fun/atan.hpp>
#include <stan/math/rev/fun/atan2.hpp>
#include <stan/math/rev/fun/atanh.hpp>
#include <stan/math/rev/fun/bessel_first_kind.hpp>
#include <stan/math/rev/fun/bessel_second_kind.hpp>
#include <stan/math/rev/fun/beta.hpp>
#include <stan/math/rev/fun/binary_log_loss.hpp>
#include <stan/math/rev/fun/cbrt.hpp>
#include <stan/math/rev/fun/ceil.hpp>
#include <stan/math/rev/fun/cholesky_decompose.hpp>
#include <stan/math/rev/fun/cholesky_corr_constrain.hpp>
#include <stan/math/rev/fun/cholesky_factor_constrain.hpp>
#include <stan/math/rev/fun/columns_dot_product.hpp>
#include <stan/math/rev/fun/columns_dot_self.hpp>
#include <stan/math/rev/fun/conj.hpp>
#include <stan/math/rev/fun/cos.hpp>
#include <stan/math/rev/fun/cosh.hpp>
#include <stan/math/rev/fun/corr_matrix_constrain.hpp>
#include <stan/math/rev/fun/cov_matrix_constrain.hpp>
#include <stan/math/rev/fun/cov_exp_quad.hpp>
#include <stan/math/rev/fun/cov_matrix_constrain_lkj.hpp>
#include <stan/math/rev/fun/csr_matrix_times_vector.hpp>
#include <stan/math/rev/fun/determinant.hpp>
#include <stan/math/rev/fun/diag_pre_multiply.hpp>
#include <stan/math/rev/fun/diag_post_multiply.hpp>
#include <stan/math/rev/fun/digamma.hpp>
#include <stan/math/rev/fun/dims.hpp>
#include <stan/math/rev/fun/divide.hpp>
#include <stan/math/rev/fun/dot_product.hpp>
#include <stan/math/rev/fun/dot_self.hpp>
#include <stan/math/rev/fun/eigenvalues_sym.hpp>
#include <stan/math/rev/fun/eigenvectors_sym.hpp>
#include <stan/math/rev/fun/elt_divide.hpp>
#include <stan/math/rev/fun/elt_multiply.hpp>
#include <stan/math/rev/fun/erf.hpp>
#include <stan/math/rev/fun/erfc.hpp>
#include <stan/math/rev/fun/exp.hpp>
#include <stan/math/rev/fun/exp2.hpp>
#include <stan/math/rev/fun/expm1.hpp>
#include <stan/math/rev/fun/fabs.hpp>
#include <stan/math/rev/fun/falling_factorial.hpp>
#include <stan/math/rev/fun/fdim.hpp>
#include <stan/math/rev/fun/fill.hpp>
#include <stan/math/rev/fun/floor.hpp>
#include <stan/math/rev/fun/fma.hpp>
#include <stan/math/rev/fun/fmax.hpp>
#include <stan/math/rev/fun/fmin.hpp>
#include <stan/math/rev/fun/fmod.hpp>
#include <stan/math/rev/fun/from_var_value.hpp>
#include <stan/math/rev/fun/gamma_p.hpp>
#include <stan/math/rev/fun/gamma_q.hpp>
#include <stan/math/rev/fun/generalized_inverse.hpp>
#include <stan/math/rev/fun/gp_periodic_cov.hpp>
#include <stan/math/rev/fun/grad.hpp>
#include <stan/math/rev/fun/grad_inc_beta.hpp>
#include <stan/math/rev/fun/hypot.hpp>
#include <stan/math/rev/fun/identity_constrain.hpp>
#include <stan/math/rev/fun/identity_free.hpp>
#include <stan/math/rev/fun/if_else.hpp>
#include <stan/math/rev/fun/inc_beta.hpp>
#include <stan/math/rev/fun/initialize_fill.hpp>
#include <stan/math/rev/fun/initialize_variable.hpp>
#include <stan/math/rev/fun/inv.hpp>
#include <stan/math/rev/fun/inv_Phi.hpp>
#include <stan/math/rev/fun/inv_cloglog.hpp>
#include <stan/math/rev/fun/inv_logit.hpp>
#include <stan/math/rev/fun/inv_sqrt.hpp>
#include <stan/math/rev/fun/inv_square.hpp>
#include <stan/math/rev/fun/inverse.hpp>
#include <stan/math/rev/fun/is_inf.hpp>
#include <stan/math/rev/fun/is_nan.hpp>
#include <stan/math/rev/fun/is_uninitialized.hpp>
#include <stan/math/rev/fun/lambert_w.hpp>
#include <stan/math/rev/fun/lb_constrain.hpp>
#include <stan/math/rev/fun/lbeta.hpp>
#include <stan/math/rev/fun/ldexp.hpp>
#include <stan/math/rev/fun/lgamma.hpp>
#include <stan/math/rev/fun/lmgamma.hpp>
#include <stan/math/rev/fun/log.hpp>
#include <stan/math/rev/fun/log10.hpp>
#include <stan/math/rev/fun/log1m.hpp>
#include <stan/math/rev/fun/log1m_exp.hpp>
#include <stan/math/rev/fun/log1m_inv_logit.hpp>
#include <stan/math/rev/fun/log1p.hpp>
#include <stan/math/rev/fun/log1p_exp.hpp>
#include <stan/math/rev/fun/log2.hpp>
#include <stan/math/rev/fun/log_determinant.hpp>
#include <stan/math/rev/fun/log_determinant_ldlt.hpp>
#include <stan/math/rev/fun/log_determinant_spd.hpp>
#include <stan/math/rev/fun/log_diff_exp.hpp>
#include <stan/math/rev/fun/log_falling_factorial.hpp>
#include <stan/math/rev/fun/log_inv_logit.hpp>
#include <stan/math/rev/fun/log_inv_logit_diff.hpp>
#include <stan/math/rev/fun/log_mix.hpp>
#include <stan/math/rev/fun/log_rising_factorial.hpp>
#include <stan/math/rev/fun/log_softmax.hpp>
#include <stan/math/rev/fun/log_sum_exp.hpp>
#include <stan/math/rev/fun/logit.hpp>
#include <stan/math/rev/fun/lub_constrain.hpp>
#include <stan/math/rev/fun/matrix_exp_multiply.hpp>
#include <stan/math/rev/fun/matrix_power.hpp>
#include <stan/math/rev/fun/mdivide_left.hpp>
#include <stan/math/rev/fun/mdivide_left_ldlt.hpp>
#include <stan/math/rev/fun/mdivide_left_spd.hpp>
#include <stan/math/rev/fun/mdivide_left_tri.hpp>
#include <stan/math/rev/fun/modified_bessel_first_kind.hpp>
#include <stan/math/rev/fun/modified_bessel_second_kind.hpp>
#include <stan/math/rev/fun/multiply.hpp>
#include <stan/math/rev/fun/multiply_log.hpp>
#include <stan/math/rev/fun/multiply_lower_tri_self_transpose.hpp>
#include <stan/math/rev/fun/norm.hpp>
#include <stan/math/rev/fun/ordered_constrain.hpp>
#include <stan/math/rev/fun/owens_t.hpp>
#include <stan/math/rev/fun/polar.hpp>
#include <stan/math/rev/fun/positive_ordered_constrain.hpp>
#include <stan/math/rev/fun/pow.hpp>
#include <stan/math/rev/fun/primitive_value.hpp>
#include <stan/math/rev/fun/proj.hpp>
#include <stan/math/rev/fun/quad_form.hpp>
#include <stan/math/rev/fun/quad_form_sym.hpp>
#include <stan/math/rev/fun/read_corr_L.hpp>
#include <stan/math/rev/fun/read_corr_matrix.hpp>
#include <stan/math/rev/fun/read_cov_L.hpp>
#include <stan/math/rev/fun/read_cov_matrix.hpp>
#include <stan/math/rev/fun/rep_matrix.hpp>
#include <stan/math/rev/fun/rep_row_vector.hpp>
#include <stan/math/rev/fun/rep_vector.hpp>
#include <stan/math/rev/fun/rising_factorial.hpp>
#include <stan/math/rev/fun/round.hpp>
#include <stan/math/rev/fun/rows_dot_product.hpp>
#include <stan/math/rev/fun/rows_dot_self.hpp>
#include <stan/math/rev/fun/sd.hpp>
#include <stan/math/rev/fun/simplex_constrain.hpp>
#include <stan/math/rev/fun/sin.hpp>
#include <stan/math/rev/fun/singular_values.hpp>
#include <stan/math/rev/fun/svd_U.hpp>
#include <stan/math/rev/fun/svd_V.hpp>
#include <stan/math/rev/fun/sinh.hpp>
#include <stan/math/rev/fun/softmax.hpp>
#include <stan/math/rev/fun/sqrt.hpp>
#include <stan/math/rev/fun/square.hpp>
#include <stan/math/rev/fun/squared_distance.hpp>
#include <stan/math/rev/fun/stan_print.hpp>
#include <stan/math/rev/fun/step.hpp>
#include <stan/math/rev/fun/sum.hpp>
#include <stan/math/rev/fun/tan.hpp>
#include <stan/math/rev/fun/tanh.hpp>
#include <stan/math/rev/fun/tcrossprod.hpp>
#include <stan/math/rev/fun/tgamma.hpp>
#include <stan/math/rev/fun/to_var.hpp>
#include <stan/math/rev/fun/to_arena.hpp>
#include <stan/math/rev/fun/to_var_value.hpp>
#include <stan/math/rev/fun/to_vector.hpp>
#include <stan/math/rev/fun/trace.hpp>
#include <stan/math/rev/fun/trace_gen_inv_quad_form_ldlt.hpp>
#include <stan/math/rev/fun/trace_gen_quad_form.hpp>
#include <stan/math/rev/fun/trace_inv_quad_form_ldlt.hpp>
#include <stan/math/rev/fun/trace_quad_form.hpp>
#include <stan/math/rev/fun/trigamma.hpp>
#include <stan/math/rev/fun/trunc.hpp>
#include <stan/math/rev/fun/unit_vector_constrain.hpp>
#include <stan/math/rev/fun/ub_constrain.hpp>
#include <stan/math/rev/fun/value_of.hpp>
#include <stan/math/rev/fun/value_of_rec.hpp>
#include <stan/math/rev/fun/variance.hpp>

#include <stan/math/prim/err.hpp>
#include <stan/math/prim/fun.hpp>
#include <stan/math/prim/functor.hpp>
#include <stan/math/prim/meta.hpp>

#endif

==> stan4bart_0.0-11.tar.gz: stan4bart/src/include/stan/math/rev/fun.hpp <==
#ifndef STAN_MATH_REV_FUN_HPP
#define STAN_MATH_REV_FUN_HPP

#include <stan/math/prim/fun/Eigen.hpp>

#include <stan/math/rev/fun/LDLT_factor.hpp>
#include <stan/math/rev/fun/Phi.hpp>
#include <stan/math/rev/fun/Phi_approx.hpp>
#include <stan/math/rev/fun/abs.hpp>
#include <stan/math/rev/fun/accumulator.hpp>
#include <stan/math/rev/fun/acos.hpp>
#include <stan/math/rev/fun/acosh.hpp>
#include <stan/math/rev/fun/append_col.hpp>
#include <stan/math/rev/fun/append_row.hpp>
#include <stan/math/rev/fun/as_bool.hpp>
#include <stan/math/rev/fun/as_array_or_scalar.hpp>
#include <stan/math/rev/fun/as_column_vector_or_scalar.hpp>
#include <stan/math/rev/fun/arg.hpp>
#include <stan/math/rev/fun/asin.hpp>
#include <stan/math/rev/fun/asinh.hpp>
#include <stan/math/rev/fun/atan.hpp>
#include <stan/math/rev/fun/atan2.hpp>
#include <stan/math/rev/fun/atanh.hpp>
#include <stan/math/rev/fun/bessel_first_kind.hpp>
#include <stan/math/rev/fun/bessel_second_kind.hpp>
#include <stan/math/rev/fun/beta.hpp>
#include <stan/math/rev/fun/binary_log_loss.hpp>
#include <stan/math/rev/fun/cbrt.hpp>
#include <stan/math/rev/fun/ceil.hpp>
#include <stan/math/rev/fun/cholesky_decompose.hpp>
#include <stan/math/rev/fun/cholesky_corr_constrain.hpp>
#include <stan/math/rev/fun/cholesky_factor_constrain.hpp>
#include <stan/math/rev/fun/cumulative_sum.hpp>
#include <stan/math/rev/fun/columns_dot_product.hpp>
#include <stan/math/rev/fun/columns_dot_self.hpp>
#include <stan/math/rev/fun/conj.hpp>
#include <stan/math/rev/fun/cos.hpp>
#include <stan/math/rev/fun/cosh.hpp>
#include <stan/math/rev/fun/corr_matrix_constrain.hpp>
#include <stan/math/rev/fun/cov_matrix_constrain.hpp>
#include <stan/math/rev/fun/cov_exp_quad.hpp>
#include <stan/math/rev/fun/cov_matrix_constrain_lkj.hpp>
#include <stan/math/rev/fun/csr_matrix_times_vector.hpp>
#include <stan/math/rev/fun/determinant.hpp>
#include <stan/math/rev/fun/diag_pre_multiply.hpp>
#include <stan/math/rev/fun/diag_post_multiply.hpp>
#include <stan/math/rev/fun/digamma.hpp>
#include <stan/math/rev/fun/dims.hpp>
#include <stan/math/rev/fun/divide.hpp>
#include <stan/math/rev/fun/dot_product.hpp>
#include <stan/math/rev/fun/dot_self.hpp>
#include <stan/math/rev/fun/eigenvalues_sym.hpp>
#include <stan/math/rev/fun/eigenvectors_sym.hpp>
#include <stan/math/rev/fun/elt_divide.hpp>
#include <stan/math/rev/fun/elt_multiply.hpp>
#include <stan/math/rev/fun/erf.hpp>
#include <stan/math/rev/fun/erfc.hpp>
#include <stan/math/rev/fun/exp.hpp>
#include <stan/math/rev/fun/exp2.hpp>
#include <stan/math/rev/fun/expm1.hpp>
#include <stan/math/rev/fun/fabs.hpp>
#include <stan/math/rev/fun/falling_factorial.hpp>
#include <stan/math/rev/fun/fdim.hpp>
#include <stan/math/rev/fun/fft.hpp>
#include <stan/math/rev/fun/fill.hpp>
#include <stan/math/rev/fun/floor.hpp>
#include <stan/math/rev/fun/fma.hpp>
#include <stan/math/rev/fun/fmax.hpp>
#include <stan/math/rev/fun/fmin.hpp>
#include <stan/math/rev/fun/fmod.hpp>
#include <stan/math/rev/fun/from_var_value.hpp>
#include <stan/math/rev/fun/gamma_p.hpp>
#include <stan/math/rev/fun/gamma_q.hpp>
#include <stan/math/rev/fun/generalized_inverse.hpp>
#include <stan/math/rev/fun/gp_periodic_cov.hpp>
#include <stan/math/rev/fun/grad.hpp>
#include <stan/math/rev/fun/grad_inc_beta.hpp>
#include <stan/math/rev/fun/hypergeometric_2F1.hpp>
#include <stan/math/rev/fun/hypergeometric_pFq.hpp>
#include <stan/math/rev/fun/hypot.hpp>
#include <stan/math/rev/fun/identity_constrain.hpp>
#include <stan/math/rev/fun/identity_free.hpp>
#include <stan/math/rev/fun/if_else.hpp>
#include <stan/math/rev/fun/inc_beta.hpp>
#include <stan/math/rev/fun/inv_inc_beta.hpp>
#include <stan/math/rev/fun/initialize_fill.hpp>
#include <stan/math/rev/fun/initialize_variable.hpp>
#include <stan/math/rev/fun/inv.hpp>
#include <stan/math/rev/fun/inv_Phi.hpp>
#include <stan/math/rev/fun/inv_cloglog.hpp>
#include <stan/math/rev/fun/inv_erfc.hpp>
#include <stan/math/rev/fun/inv_logit.hpp>
#include <stan/math/rev/fun/inv_sqrt.hpp>
#include <stan/math/rev/fun/inv_square.hpp>
#include <stan/math/rev/fun/inverse.hpp>
#include <stan/math/rev/fun/is_inf.hpp>
#include <stan/math/rev/fun/is_nan.hpp>
#include <stan/math/rev/fun/is_uninitialized.hpp>
#include <stan/math/rev/fun/lambert_w.hpp>
#include <stan/math/rev/fun/lb_constrain.hpp>
#include <stan/math/rev/fun/lbeta.hpp>
#include <stan/math/rev/fun/ldexp.hpp>
#include <stan/math/rev/fun/lgamma.hpp>
#include <stan/math/rev/fun/lmgamma.hpp>
#include <stan/math/rev/fun/lmultiply.hpp>
#include <stan/math/rev/fun/log.hpp>
#include <stan/math/rev/fun/log10.hpp>
#include <stan/math/rev/fun/log1m.hpp>
#include <stan/math/rev/fun/log1m_exp.hpp>
#include <stan/math/rev/fun/log1m_inv_logit.hpp>
#include <stan/math/rev/fun/log1p.hpp>
#include <stan/math/rev/fun/log1p_exp.hpp>
#include <stan/math/rev/fun/log2.hpp>
#include <stan/math/rev/fun/log_determinant.hpp>
#include <stan/math/rev/fun/log_determinant_ldlt.hpp>
#include <stan/math/rev/fun/log_determinant_spd.hpp>
#include <stan/math/rev/fun/log_diff_exp.hpp>
#include <stan/math/rev/fun/log_falling_factorial.hpp>
#include <stan/math/rev/fun/log_inv_logit.hpp>
#include <stan/math/rev/fun/log_inv_logit_diff.hpp>
#include <stan/math/rev/fun/log_mix.hpp>
#include <stan/math/rev/fun/log_rising_factorial.hpp>
#include <stan/math/rev/fun/log_softmax.hpp>
#include <stan/math/rev/fun/log_sum_exp.hpp>
#include <stan/math/rev/fun/logit.hpp>
#include <stan/math/rev/fun/lub_constrain.hpp>
#include <stan/math/rev/fun/matrix_exp_multiply.hpp>
#include <stan/math/rev/fun/matrix_power.hpp>
#include <stan/math/rev/fun/mdivide_left.hpp>
#include <stan/math/rev/fun/mdivide_left_ldlt.hpp>
#include <stan/math/rev/fun/mdivide_left_spd.hpp>
#include <stan/math/rev/fun/mdivide_left_tri.hpp>
#include <stan/math/rev/fun/modified_bessel_first_kind.hpp>
#include <stan/math/rev/fun/modified_bessel_second_kind.hpp>
#include <stan/math/rev/fun/multiply.hpp>
#include <stan/math/rev/fun/multiply_log.hpp>
#include <stan/math/rev/fun/multiply_lower_tri_self_transpose.hpp>
#include <stan/math/rev/fun/norm.hpp>
#include <stan/math/rev/fun/norm1.hpp>
#include <stan/math/rev/fun/norm2.hpp>
#include <stan/math/rev/fun/ordered_constrain.hpp>
#include <stan/math/rev/fun/owens_t.hpp>
#include <stan/math/rev/fun/polar.hpp>
#include <stan/math/rev/fun/positive_ordered_constrain.hpp>
#include <stan/math/rev/fun/pow.hpp>
#include <stan/math/rev/fun/primitive_value.hpp>
#include <stan/math/rev/fun/proj.hpp>
#include <stan/math/rev/fun/quad_form.hpp>
#include <stan/math/rev/fun/quad_form_sym.hpp>
#include <stan/math/rev/fun/read_corr_L.hpp>
#include <stan/math/rev/fun/read_corr_matrix.hpp>
#include <stan/math/rev/fun/read_cov_L.hpp>
#include <stan/math/rev/fun/read_cov_matrix.hpp>
#include <stan/math/rev/fun/rep_matrix.hpp>
#include <stan/math/rev/fun/rep_row_vector.hpp>
#include <stan/math/rev/fun/rep_vector.hpp>
#include <stan/math/rev/fun/rising_factorial.hpp>
#include <stan/math/rev/fun/round.hpp>
#include <stan/math/rev/fun/rows_dot_product.hpp>
#include <stan/math/rev/fun/rows_dot_self.hpp>
#include <stan/math/rev/fun/sd.hpp>
#include <stan/math/rev/fun/simplex_constrain.hpp>
#include <stan/math/rev/fun/sin.hpp>
#include <stan/math/rev/fun/singular_values.hpp>
#include <stan/math/rev/fun/svd_U.hpp>
#include <stan/math/rev/fun/svd_V.hpp>
#include <stan/math/rev/fun/sinh.hpp>
#include <stan/math/rev/fun/softmax.hpp>
#include <stan/math/rev/fun/sqrt.hpp>
#include <stan/math/rev/fun/square.hpp>
#include <stan/math/rev/fun/squared_distance.hpp>
#include <stan/math/rev/fun/stan_print.hpp>
#include <stan/math/rev/fun/step.hpp>
#include <stan/math/rev/fun/sum.hpp>
#include <stan/math/rev/fun/tan.hpp>
#include <stan/math/rev/fun/tanh.hpp>
#include <stan/math/rev/fun/tcrossprod.hpp>
#include <stan/math/rev/fun/tgamma.hpp>
#include <stan/math/rev/fun/to_var.hpp>
#include <stan/math/rev/fun/to_arena.hpp>
#include <stan/math/rev/fun/to_var_value.hpp>
#include <stan/math/rev/fun/to_vector.hpp>
#include <stan/math/rev/fun/trace.hpp>
#include <stan/math/rev/fun/trace_gen_inv_quad_form_ldlt.hpp>
#include <stan/math/rev/fun/trace_gen_quad_form.hpp>
#include <stan/math/rev/fun/trace_inv_quad_form_ldlt.hpp>
#include <stan/math/rev/fun/trace_quad_form.hpp>
#include <stan/math/rev/fun/trigamma.hpp>
#include <stan/math/rev/fun/trunc.hpp>
#include <stan/math/rev/fun/unit_vector_constrain.hpp>
#include <stan/math/rev/fun/ub_constrain.hpp>
#include <stan/math/rev/fun/value_of.hpp>
#include <stan/math/rev/fun/value_of_rec.hpp>
#include <stan/math/rev/fun/variance.hpp>

#include <stan/math/prim/err.hpp>
#include <stan/math/prim/fun.hpp>
#include <stan/math/prim/functor.hpp>
#include <stan/math/prim/meta.hpp>

#endif
